[![kinisi Logo](https://github.com/bjmorgan/kinisi/raw/master/docs/source/logo/kinisi_logo.png)](https://kinisi.readthedocs.io)

kee-nee-si

[![Test Coverage](https://api.codeclimate.com/v1/badges/3e64239fb6cb6c837b62/test_coverage)](https://codeclimate.com/github/bjmorgan/kinisi/test_coverage)
[![Documentation Status](https://readthedocs.org/projects/kinisi/badge/?version=latest)](https://kinisi.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/kinisi.svg)](https://badge.fury.io/py/kinisi)

Uncertainty analysis and model comparison for diffusion in molecular dynamics.

## Installation

`kinisi` is available from the [PyPI](https://pypi.org/project/kinisi/) repository so can be [installed using `pip`](https://kinisi.readthedocs.io/en/latest/installation.html) or alternatively `clone` this repository and install the latest development build with the commands below.

```
pip install -r requirements.txt
python setup.py install
pytest
```
